@@ -17,7 +17,7 @@ import time
 from urllib.parse import urlsplit
 
 import aiohttp
-from aiohttp import server, helpers
+from aiohttp import server, helpers, hdrs
 
 
 class WSGIServerHttpProtocol(server.ServerHttpProtocol):
@@ -71,7 +71,7 @@ class WSGIServerHttpProtocol(server.ServerHttpProtocol):
         script_name = self.SCRIPT_NAME
         server = forward
 
-        for hdr_name, hdr_value in message.headers.items(getall=True):
+        for hdr_name, hdr_value in message.headers.items():
             if hdr_name == 'HOST':
                 server = hdr_value
             elif hdr_name == 'SCRIPT_NAME':
@@ -174,6 +174,17 @@ class WsgiResponse:
 
     status = None
 
+    HOP_HEADERS = {
+        hdrs.CONNECTION,
+        hdrs.KEEP_ALIVE,
+        hdrs.PROXY_AUTHENTICATE,
+        hdrs.PROXY_AUTHORIZATION,
+        hdrs.TE,
+        hdrs.TRAILER,
+        hdrs.TRANSFER_ENCODING,
+        hdrs.UPGRADE,
+    }
+
     def __init__(self, writer, message):
         self.writer = writer
         self.message = message
@@ -192,8 +203,12 @@ class WsgiResponse:
         resp = self.response = aiohttp.Response(
             self.writer, status_code,
             self.message.version, self.message.should_close)
+        resp.HOP_HEADERS = self.HOP_HEADERS
         resp.add_headers(*headers)
 
+        if resp.has_chunked_hdr:
+            resp.enable_chunked_encoding()
+
         # send headers immediately for websocket connection
         if status_code == 101 and resp.upgrade and resp.websocket:
             resp.send_headers()
